#ifndef XPETRA_CONFIG_HPP
#define XPETRA_CONFIG_HPP

/* #undef HAVE_XPETRA_DEBUG */

#define HAVE_XPETRA_TPETRA

#define HAVE_XPETRA_EPETRA

#define HAVE_XPETRA_KOKKOSCORE

#define HAVE_XPETRA_KOKKOSCONTAINERS

/* #undef HAVE_XPETRA_KOKKOS_REFACTOR */

/* #undef HAVE_XPETRA_KOKKOSCLASSIC */

#define HAVE_XPETRA_THYRA

#define HAVE_XPETRA_EPETRAEXT

/* #undef HAVE_XPETRA_PROFILING */

/* #undef HAVE_XPETRA_EXPERIMENTAL */

/* #undef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES */

/* #undef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES */

#endif // XPETRA_CONFIG_HPP
